@@ -1,7 +1,7 @@
 package App::genpw::id;
 
-our $DATE = '2018-01-09'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2020-05-21'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,6 +24,7 @@ sub genpw {
     my %args = @_;
 
     App::genpw::wordlist::genpw(
+        (action => $args{action})     x !!defined($args{action}),
         (num => $args{num})           x !!defined($args{num}),
         (patterns => $args{patterns}) x !!defined($args{patterns}),
         wordlists => ['ID::KBBI'],
@@ -45,7 +46,7 @@ App::genpw::id - Generate password from combination of Indonesian words
 
 =head1 VERSION
 
-This document describes version 0.005 of App::genpw::id (from Perl distribution App-genpw-id), released on 2018-01-09.
+This document describes version 0.006 of App::genpw::id (from Perl distribution App-genpw-id), released on 2020-05-21.
 
 =head1 SYNOPSIS
 
@@ -58,7 +59,7 @@ See the included script L<genpwxs-id>.
 
 Usage:
 
- genpw(%args) -> [status, msg, result, meta]
+ genpw(%args) -> [status, msg, payload, meta]
 
 Generate password from combination of Indonesian words.
 
@@ -80,6 +81,8 @@ Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<action> => I<str> (default: "gen")
+
 =item * B<case> => I<str> (default: "default")
 
 Force casing.
@@ -102,9 +105,13 @@ be used as-is. Available conversions:
 
  %l   Random Latin letter (A-Z, a-z)
  %d   Random digit (0-9)
+ %h   Random hexdigit (0-9a-f)
  %a   Random letter/digit (Alphanum) (A-Z, a-z, 0-9; combination of %l and %d)
  %s   Random ASCII symbol, e.g. "-" (dash), "_" (underscore), etc.
  %x   Random letter/digit/ASCII symbol (combination of %a and %s)
+ %m   Base64 character (A-Z, a-z, 0-9, +, /)
+ %b   Base58 character (A-Z, a-z, 0-9 minus IOl0)
+ %B   Base56 character (A-Z, a-z, 0-9 minus IOol01)
  %%   A literal percent sign
  %w   Random word
 
@@ -112,6 +119,7 @@ be used as-is. Available conversions:
 
 Select one or more wordlist modules.
 
+
 =back
 
 Returns an enveloped result (an array).
@@ -119,7 +127,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -131,7 +139,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-genpw-
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-App-Genpass-ID>.
+Source repository is at L<https://github.com/perlancar/perl-App-genpw-id>.
 
 =head1 BUGS
 
@@ -147,7 +155,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018, 2017 by perlancar@cpan.org.
+This software is copyright (c) 2020, 2018, 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
